gchecky.model.excluded_areas_t

Package gchecky :: Module model :: Class excluded_areas_t |
[hide private]
[frames] | no frames]

# Class excluded_areas_t

source code

    object --+
             |
     gxml.Node --+
                 |
           areas_t --+
                     |
                    excluded_areas_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| postal_areas = `List:PATH():OP`...``
| _fields = ``{``'``country_areas``'``:` List:PATH():OPT:VALS("CONTINENTAL_`...`` list of meta-Fields of this class.
Inherited from `areas_t`: `country_areas`, `states`, `zip_patterns`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### postal_areas Value:
      List:PATH():OPT:[
          Node:PATH(postal-area):REQ:{ postal_area_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'country_areas': List:PATH():OPT:VALS("CONTINENTAL_48","FULL_50_STATE
      S","ALL"):[
          String:PATH(us-country-area/country-area):REQ
      ],
       'postal_areas': List:PATH():OPT:[
          Node:PATH(postal-area):REQ:{ postal_area_t }
      ],
       'states': List:PATH():OPT:[
      ...